@@ -20,7 +20,7 @@ from typing import (
 )
 
 from cached_property import cached_property
-from pydantic import Field, root_validator
+from pydantic.v1 import Field, root_validator
 
 from ..environment import (
     ASDF_DATA_DIR,
